@@ -6,5 +6,6 @@ var structPrimaryMultiThreadInfo =
     [ "tile_thr_data", "structPrimaryMultiThreadInfo.html#a6494f42ca4102a605f2918a304258d69", null ],
     [ "cdef_worker", "structPrimaryMultiThreadInfo.html#a649d4b8472abb57bc3e63dd1500ccc3e", null ],
     [ "p_workers", "structPrimaryMultiThreadInfo.html#a892dc2ef5c9c196a09c5421d3711f66c", null ],
-    [ "p_num_workers", "structPrimaryMultiThreadInfo.html#ab4afd254b42199d2aa7019c6755a5e03", null ]
+    [ "p_num_workers", "structPrimaryMultiThreadInfo.html#ab4afd254b42199d2aa7019c6755a5e03", null ],
+    [ "prev_num_enc_workers", "structPrimaryMultiThreadInfo.html#a83daf53d826d3a12c55688df8113c223", null ]
 ];
\ No newline at end of file
